"""
pyvitemadose use case
"""

import sys
import requests
import re
import platform
from termcolor import colored

from pyvitemadose.args import compute_args


def find(dept):

    if compute_args().before and not re.match(
        "[0-9][0-9][0-9][0-9]\-[0-9][0-9]\-[0-9][0-9]",
        str(compute_args().before),
    ):
        print(
            str(compute_args().before)
            + " : no valid format date, use yyyy-mm-dd format please"
        )
        sys.exit(1)
    trouve = False
    r = requests.get(
        "https://vitemadose.gitlab.io/vitemadose/"
        + dept.zfill(2)
        + ".json"
    )
    if str(r) != "<Response [200]>":
        print(str(r) + " : no data found, verify the departement")
        sys.exit(1)
    for centre in r.json().get("centres_disponibles", []):
        if centre.get("appointment_count", "") != 0:
            if (
                not compute_args().before
                or str(centre.get("prochain_rdv")[0:10])
                <= compute_args().before
            ):
                trouve = True
                printcoloredandemoji(
                    str(centre.get("prochain_rdv")[0:10]) + ", " + centre.get("metadata").get("address"),"green","\U0001F4C5"
                )
                printcoloredandemoji(centre.get("url"),"green","\U0001F517")
                printcoloredandemoji(
                    str(centre.get("appointment_count")) + " " + str(centre.get("vaccine_type")),"yellow","\U0001F489"
                )
                print("")
    if not trouve:
        print("pas de creneaux trouves...")
        sys.exit(2)


def printcoloredandemoji(phrase, color, emoji):
    if compute_args().nocolor:
        print(phrase)
    elif platform.system().lower() in "windows":
        print(colored(phrase,color))
    else:        
        print(colored(emoji+ " " + phrase,color))


"""
pyvitemadose init
"""

from os import sys
from pyvitemadose.args import compute_args, is_pyinstaller
from pyvitemadose.pyvitemadose import find
from pyvitemadose.update import update

def pyvitemadose():
    """
    pyvitemadose entry point
    """
    args = compute_args()

    if args.update:
        if not is_pyinstaller():
            update()
        else:
            print("update is disabled. Do you use a bundle?")
    if args.departement:
        find(args.departement)
    sys.exit(0)

pyvitemadose()


from setuptools import setup


setup(
    name="pyvitemadose",
    version="2.0.0",
    description="pyvitemadose displays available chronodoses of covid vaccine for your departement in France",
    long_description="The complete description/installation/use/FAQ is available at : https://github.com/thib1984/pyvitemadose#readme",
    url="https://github.com/thib1984/pyvitemadose",
    author="thib1984",
    author_email="thibault.garcon@gmail.com",
    license="MIT",
    license_files="LICENSE.txt",
    packages=["pyvitemadose"],
    install_requires=["requests","termcolor"],
    zip_safe=False,
    entry_points={
        "console_scripts": [
            "pyvitemadose=pyvitemadose.__init__:pyvitemadose"
        ],
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.10",
)
